@@ -5,20 +5,25 @@
 #' @param real is to judge whether the data set is a real missing data set
 #' @param example is to judge whether the data set is a simulation example.
 #'
-#' @return XSR, MSESR, MAESR, RESR, GCVSR
+#' @return
+#' \item{XSR}{is the estimator on the SR method}
+#' \item{MSESR}{is the MSE value of the SR method}
+#' \item{MAESR}{is the MAE value of the SR method}
+#' \item{RESR}{is the RE value of the SR method}
+#' \item{GCVSR}{is the GCV value of the SR method}
 #' @export
-#'
-#' @examples 
-#'  library(MASS)   
+#' @importFrom stats cor
+#' @importFrom MASS ginv
+#' @examples
+#'  library(MASS)
 #'  n=100;p=10;per=0.1
 #'  X0=data=matrix(mvrnorm(n*p,0,1),n,p)
 #'  m=round(per*n*p,digits=0)
 #'  mr=sample(1:(n*p),m,replace=FALSE)
 #'  X0[mr]=NA;data0=X0
 #'  SR(data=data,data0=data0,real=FALSE,example=FALSE)
-
-#the SR method 
-SR=function(data=0,data0,real=TRUE,example=FALSE)
+#the SR method
+SR=function(data,data0,real=TRUE,example=FALSE)
 #It defaults that the data set is a real data set
 {#1
   if (real||example){#2
@@ -33,7 +38,7 @@ SR=function(data=0,data0,real=TRUE,example=FALSE)
   ina=as.matrix(mr%%n)
   jna=as.matrix(floor((mr+n-1)/n))
   cm0=colMeans(X0,na.rm=T)
-  data0[is.na(data0)]=0	
+  data0[is.na(data0)]=0
   X=Xold=as.matrix(data0)
   lambda=svd(cor(X))$d
   l=lambda/sum(lambda)
@@ -56,13 +61,13 @@ SR=function(data=0,data0,real=TRUE,example=FALSE)
       Aina=matrix(Ak[jna,],pina,k,byrow=FALSE)
       Ti=Xiob%*%Aiob;Ti
       betaihat=ginv(t(Ti)%*%Ti)%*%t(Ti)%*%Xina;betaihat
-      xinahat=xiob%*%Aiob%*%betaihat;xinahat	
+      xinahat=xiob%*%Aiob%*%betaihat;xinahat
       X[i,jna]=xinahat
       Xnew=X
       pina=0
     }#3
   }#2
-  XSR=Xnew    
+  XSR=Xnew
   for (j in 1:p){#2
     Mj=is.na(X0[,j])
     iob=which(Mj==FALSE)
@@ -77,14 +82,14 @@ SR=function(data=0,data0,real=TRUE,example=FALSE)
     MSESR= MAESR= RESR='NULL'
   }else{#2
     MSESR=(1/m)*t(Xnew[mr]-data[mr])%*%(Xnew[mr]-data[mr])
-    MAESR=(1/m)*sum(abs(Xnew[mr]-data[mr]))	
+    MAESR=(1/m)*sum(abs(Xnew[mr]-data[mr]))
     RESR=(sum(abs(data[mr]-Xnew[mr])))/(sum(data[mr]))
   }#2
   lambdaSR=svd(cor(XSR))$d;lambdaSR
   lSR=lambdaSR/sum(lambdaSR);J=rep(lSR,times=p);dim(J)=c(p,p)
   upper.tri(J,diag=T);J[lower.tri(J)]=0;J;dim(J)=c(p,p)
   etaSR=matrix(colSums(J),nrow = 1,ncol = p,byrow = FALSE)
-  wwSR=which(etaSR>=etatol);kSR=wwSR[1] 
+  wwSR=which(etaSR>=etatol);kSR=wwSR[1]
   lambdaSRpk=lambdaSR[(kSR+1):p]
   GCVSR=sum(lambdaSRpk)*p/(p-kSR)^2
   return(list(XSR=XSR,MSESR=MSESR,MAESR=MAESR,RESR=RESR,GCVSR=GCVSR))
